import { useState } from "react";
import user from "../../data/users.json";

const Login = () => {
  const [authForm, setAuthForm] = useState({
    email: '',
    password: ''
  });

  const [err, setErr] = useState({
    err: false,
    message: ''
  });

  const handleAuthForm = (e) => {
    if(err.err) {
      setErr({ ...err, err: false})
    }
    const name = e.target.name;
    const val = name === "email" ? e.target.value.toLowerCase() : e.target.value;
    setAuthForm({ ...authForm, [name]: val });
  }

  const handleSubmit = (e) => {
    e.preventDefault()
    const current_user = user.find(x => x.email == authForm.email);

    if (!current_user) {
      setErr({ err: true,  message: "User not found with this Email / Password"})
      return;
    }

    const isPassword = authForm.password === current_user.password

    if(!isPassword) {
      setErr({ err: true, message: "User not found with this Email / Password"})
      return;
    }

    console.log(current_user);
  }

  return (
    <>
      <div className="flex min-h-full flex-1 flex-col justify-center px-6 py-12 lg:px-8">
        <div className="sm:mx-auto sm:w-full sm:max-w-sm">
          <h2 className="mt-10 text-center text-2xl font-bold leading-9 tracking-tight text-gray-900">
            Sign in
          </h2>
        </div>

        <div className="mt-10 sm:mx-auto sm:w-full sm:max-w-sm">
          <form onSubmit={handleSubmit} className="space-y-6" >
            <div>
              <label htmlFor="email" className="block text-sm font-medium leading-6 text-gray-900">
                Email address
              </label>
              <div className="mt-2">
                <input
                  id="email"
                  name="email"
                  value={authForm.email}
                  onChange={handleAuthForm}
                  type="email"
                  autoComplete="email"
                  required
                  className="block w-full rounded-md border-0 py-1.5 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 placeholder:text-gray-400 focus:ring-2 focus:ring-inset focus:ring-indigo-600 sm:text-sm sm:leading-6"
                />
              </div>
            </div>

            <div>
              <div className="flex items-center justify-between">
                <label htmlFor="password" className="block text-sm font-medium leading-6 text-gray-900">
                  Password
                </label>
              </div>
              <div className="mt-2">
                <input
                  id="password"
                  name="password"
                  value={authForm.password}
                  onChange={handleAuthForm}
                  type="password"
                  autoComplete="current-password"
                  required
                  className="block w-full rounded-md border-0 py-1.5 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 placeholder:text-gray-400 focus:ring-2 focus:ring-inset focus:ring-indigo-600 sm:text-sm sm:leading-6"
                />
              </div>
            </div>
            <div>
              <button
                className="flex w-full justify-center rounded-md bg-indigo-600 px-3 py-1.5 text-sm font-semibold leading-6 text-white shadow-sm hover:bg-indigo-500 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-indigo-600"
                type="submit"
              >
                Sign in
              </button>
              { err.err && 
                <label className="text-center block text-sm font-medium leading-6 text-red-400 mt-4">
                    {err.message}
                </label>
              }
            </div>
          </form>
        </div>
      </div>
    </>
  )
}

export default Login;